@@ -3,7 +3,8 @@
 ;;; Code:
 
 
-;;;### (autoloads nil "preview" "preview.el" (21885 33555 86117 200000))
+;;;### (autoloads nil "preview" "preview.el" (22087 62999 545810
+;;;;;;  200000))
 ;;; Generated autoloads from preview.el
 
 (autoload 'preview-install-styles "preview" "\
@@ -25,7 +26,6 @@ This is called by `LaTeX-mode-hook' and changes AUCTeX variables
 to add the preview functionality.
 
 \(fn)" nil nil)
- (add-hook 'LaTeX-mode-hook #'LaTeX-preview-setup)
 
 (autoload 'preview-report-bug "preview" "\
 Report a bug in the preview-latex package.
@@ -42,8 +42,3 @@ Report a bug in the preview-latex package.
 ;; coding: utf-8
 ;; End:
 ;;; preview-latex.el ends here
-
-(defvar preview-lispdir (expand-file-name "auctex" (file-name-directory load-file-name)))
-(add-to-list 'load-path preview-lispdir)
-(defvar preview-datadir (expand-file-name "auctex" (file-name-directory load-file-name)))
-
